@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.PersonalizeRuntime 1.24.51\nVersion:         1.24.51\nBuilder"
-        " version: 7.11.6\nDocs:           "
+        "Type annotations for boto3.PersonalizeRuntime 1.26.0\nVersion:        "
+        " 1.26.0.post1\nBuilder version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime//\nBoto3 docs: "
         "     https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-runtime.html#PersonalizeRuntime\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.51")
+    print("1.26.0.post1")
 
 
 def main() -> None:
